@@ -59,14 +59,6 @@ test_that("c_across.(!) negates column", {
   expect_equal(results_df$pasted,  c(2.5, 3.5, 4.5))
 })
 
-test_that("c_across.() can only be used inside mutate_rowwise.()", {
-  test_df <- data.table(x = 1:3, y = 4:6, z = c("a", "a", "b"))
-
-
-  expect_error(test_df %>%
-    mutate.(pasted = paste0(c_across.(!z))))
-})
-
 test_that("c_across.() works with space named columns", {
   test_df <- data.table(`x y`=1:3, `x z`=1, y=3)
   resultdf <- test_df %>%
